@@ -1,6 +1,6 @@
 import unittest
 
-from shipa.client.client import ShipaClient, ShipaException, CONST_TEST_TOKEN, CONST_TEST_SERVER
+from shipa.client.client import ShipaClient, CONST_TEST_TOKEN, CONST_TEST_SERVER
 from shipa.client.http import MockResponse, MockClient
 
 
@@ -13,16 +13,13 @@ class ShipaNodeTestCase(unittest.TestCase):
             client = ShipaClient(server=CONST_TEST_SERVER, client=http, token=CONST_TEST_TOKEN)
             client.node_add(pools=tuple('test-app'), address="http://localhost", iaas="dockermachine", driver="generic")
 
-        except ShipaException as e:
+        except Exception as e:
             assert e is None, str(e)
 
     def test_node_add_failed(self):
-        try:
-            response = MockResponse(code=400, text='{"Message":"","Error":"Node address shouldn\'t repeat"}')
-            http = MockClient(response=response)
-            client = ShipaClient(server=CONST_TEST_SERVER, client=http, token=CONST_TEST_TOKEN)
-            client.node_add(pools=tuple('test-app'))
-            assert False, 'failed to add a node!'
+        response = MockResponse(code=400, text='{"Message":"","Error":"Node address shouldn\'t repeat"}')
+        http = MockClient(response=response)
+        client = ShipaClient(server=CONST_TEST_SERVER, client=http, token=CONST_TEST_TOKEN)
 
-        except ShipaException:
-            pass
+        with self.assertRaises(Exception):
+            client.node_add(pools=tuple('test-app'))
