@@ -1,6 +1,6 @@
 import unittest
 
-from shipa.client.client import ShipaClient, ShipaException, CONST_TEST_SERVER, CONST_TEST_TOKEN
+from shipa.client.client import ShipaClient, CONST_TEST_SERVER, CONST_TEST_TOKEN
 from shipa.client.http import MockResponse, MockClient
 
 
@@ -13,19 +13,16 @@ class ShipaPoolTestCase(unittest.TestCase):
             client = ShipaClient(server=CONST_TEST_SERVER, client=http, token=CONST_TEST_TOKEN)
             client.pool_add(pool="test")
 
-        except ShipaException as e:
+        except Exception as e:
             assert e is None, str(e)
 
     def test_pool_create_failed(self):
-        try:
-            response = MockResponse(code=400, text='failed to create a pool')
-            http = MockClient(response=response)
-            client = ShipaClient(server=CONST_TEST_SERVER, client=http, token=CONST_TEST_TOKEN)
-            client.pool_add(pool="test")
-            assert False, response.text
+        response = MockResponse(code=400, text='failed to create a pool')
+        http = MockClient(response=response)
+        client = ShipaClient(server=CONST_TEST_SERVER, client=http, token=CONST_TEST_TOKEN)
 
-        except ShipaException:
-            pass
+        with self.assertRaises(Exception):
+            client.pool_add(pool="test")
 
     def test_pool_remove(self):
         try:
@@ -34,19 +31,16 @@ class ShipaPoolTestCase(unittest.TestCase):
             client = ShipaClient(server=CONST_TEST_SERVER, client=http, token=CONST_TEST_TOKEN)
             client.pool_remove(pool="test")
 
-        except ShipaException as e:
+        except Exception as e:
             assert e is None, str(e)
 
     def test_pool_remove_failed(self):
-        try:
-            response = MockResponse(code=400, text='failed to remove a pool')
-            http = MockClient(response=response)
-            client = ShipaClient(server=CONST_TEST_SERVER, client=http, token=CONST_TEST_TOKEN)
-            client.pool_remove(pool="test")
-            assert False, response.text
+        response = MockResponse(code=400, text='failed to remove a pool')
+        http = MockClient(response=response)
+        client = ShipaClient(server=CONST_TEST_SERVER, client=http, token=CONST_TEST_TOKEN)
 
-        except ShipaException:
-            pass
+        with self.assertRaises(Exception):
+            client.pool_remove(pool="test")
 
     def test_pool_update(self):
         try:
@@ -55,16 +49,13 @@ class ShipaPoolTestCase(unittest.TestCase):
             client = ShipaClient(server=CONST_TEST_SERVER, client=http, token=CONST_TEST_TOKEN)
             client.pool_update(pool="test")
 
-        except ShipaException as e:
+        except Exception as e:
             assert e is None, str(e)
 
     def test_pool_update_failed(self):
-        try:
-            response = MockResponse(code=400, text='failed to update a pool')
-            http = MockClient(response=response)
-            client = ShipaClient(server=CONST_TEST_SERVER, client=http, token=CONST_TEST_TOKEN)
-            client.pool_update(pool="test")
-            assert False, response.text
+        response = MockResponse(code=400, text='failed to update a pool')
+        http = MockClient(response=response)
+        client = ShipaClient(server=CONST_TEST_SERVER, client=http, token=CONST_TEST_TOKEN)
 
-        except ShipaException:
-            pass
+        with self.assertRaises(Exception):
+            client.pool_update(pool="test")
