@@ -16,19 +16,13 @@ class ShipaUtilsTestCase(unittest.TestCase):
             assert e is None, str(e)
 
     def test_validate_map_failed(self):
-        try:
-            values = ('key',)
-            validate_map(None, None, values)
-            assert False, "passed with invalid data"
+        values = ('key',)
 
-        except click.BadParameter as e:
-            pass
+        with self.assertRaises(Exception):
+            validate_map(None, None, values)
 
     def test_validate_map_failed_invalid_value(self):
-        try:
-            values = ('key=value=key',)
-            validate_map(None, None, values)
-            assert False, "passed with invalid data"
+        values = ('key=value=key',)
 
-        except click.BadParameter as e:
-            pass
+        with self.assertRaises(Exception):
+            validate_map(None, None, values)
